<?php
/**
 * "Yet Another Multicolumn Layout" for Drupal
 *
 * (en) Central template for global theme functions
 * (de) Zentrales Template für globale Theme-Funktionen
 *
 * @copyright       Copyright 2006-2008, Alexander Hass
 * @license         http://www.yaml-fuer-drupal.de/en/terms-of-use
 * @link            http://www.yaml-for-drupal.com
 * @package         yaml-for-drupal
 * @version         5.x-3.0.4.8
 * @lastmodified    2008-02-28
 */

/**
 * This snippet changes primary links layout
 */
function phptemplate_links_primary($links) {
  $output = '';
  $count = 1;
  if (count($links)) {
    $output .= '<ul>';
    foreach ($links as $link) {
      $output .= '<li';
      if (((drupal_get_normal_path($link['href']) == $_GET['q']) || (drupal_is_front_page() && $link['href'] == '<front>')) && $count == 1) {
        $output .= ' id="current"';
        // Prevent duplication of id for html validity
        $count++;
      }
      $output .= '>'. l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment']) ."</li>\n";
    }
    $output .= '</ul>';
  }
  return $output;
}

/**
 * This snippet changes seconday links layout
 */
function phptemplate_links_secondary($links, $delimiter = ' | ', $leftcab = '', $rightcab = '') {
  // Display the left cap of the 'button bar'
  $output  = '';
  $output .= $leftcab;
  $link_count = count($links);
  $current = 1;
  foreach ($links as $link) {
      $output .= l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment']);
      // Only print the delimiter if not the last link
      if ($current < $link_count) {
        $output .= $delimiter;
      }
      $current++;
  }
  // Display the right cap of the 'button bar'
  $output .= $rightcab;

  return $output;
}

/**
 * This snippet changes default menu layout
 */
function phptemplate_menu_tree($pid = 1) {
  if ($tree = menu_tree($pid)) {
    $output .= '<ul class="menu">';
    $output .= $tree;
    $output .= '</ul>';
    return $output;
  }
}
function phptemplate_menu_item($mid, $children = '', $leaf = TRUE) {
  return '<li class="'. ($leaf ? 'leaf' : ($children ? 'expanded' : 'collapsed')) .'">'. menu_item_link($mid) . $children ."</li>\n";
}

/**
 * This snippet will add module styles if module is installed and active.
 * TODO: Add CSS only if page requires file.
 */
function _yaml_add_css_modules($base_theme_directory = '') {

  // Add module styles if modules exists
  // The unique modules directory name should be used as CSS filename.
  if (module_exists('menu_block_split')) {
    drupal_add_css($base_theme_directory .'/css/modules/menu_block_split.css', 'theme');
  }
  if (module_exists('jrating')) {
    drupal_add_css($base_theme_directory .'/css/modules/jrating.css', 'theme');
  }
  if (module_exists('service_links')) {
    drupal_add_css($base_theme_directory .'/css/modules/service_links.css', 'theme');
  }
  if (module_exists('site_map') && arg(0) == 'sitemap') {
    drupal_add_css($base_theme_directory .'/css/modules/site_map.css', 'theme');
  }

  // Add non Drupal modules here.
  // To avoid naming conflicts an underscore should be added as prefix
  // to CSS filenames of modules not contributed on drupal.org.
  // if (foo == bar) {
  //   drupal_add_css($base_theme_directory .'/css/modules/_example.css', 'theme');
  // }

}

/**
 * Add backlinks required by license to footer.
 *
 * This back linking maybe only removed, if you possess
 * a YAML Framework and YAML for Drupal license.
 *
 * For more information read the "YAML" and "YAML for Drupal" license, please.
 *
 * Licenses:
 * YAML - http://www.yaml.de
 * YAML for Drupal - http://www.yaml-for-drupal.com
 */
function phptemplate_footer_message($output = '', $delimiter = ' | ', $leftcab = '', $rightcab = '') {

  $footer_items = array();

  // If you don't like the validation links, simply uncheck on theme settings page.
  // $footer_items[] = t('<a href="http://validator.w3.org/check/referer" title="Validate XHTML">XHTML</a>');
  // $footer_items[] = t('<a href="http://jigsaw.w3.org/css-validator/check/referer" title="Validate CSS">CSS</a>');

  /**
   * GERMAN:
   * Diese Rückverlinkung darf nur entfernt werden,
   * wenn Sie eine YAML-Framework Lizenz besitzen.
   * :: Lizenzbedingungen: http://www.yaml.de
   *
   * ENGLISH:
   * This back linking maybe only removed,
   * if you possess a YAML Framework license.
   * :: License conditions: http://www.yaml.de
   */
  $footer_items[] = t('Layout based on <a href="http://www.yaml.de/">YAML</a>');

  /**
   * GERMAN:
   * Diese Rückverlinkung darf nur entfernt werden,
   * wenn Sie eine YAML für Drupal Lizenz besitzen.
   * :: Lizenzbedingungen: http://www.yaml-fuer-drupal.de
   *
   * ENGLISH:
   * This back linking maybe only removed,
   * if you have possess a YAML for Drupal license.
   * :: License conditions: http://www.yaml-for-drupal.com
   */
  $footer_items[] = t('<a href="http://www.yaml-fuer-drupal.de/" title="YAML for Drupal Theme">YAML for Drupal</a> Theme');

  // Count items and add delimiters
  $footer_links_count = count($footer_items);
  $footer_links_current = 1;
  $footer_links_output = '';
  foreach ($footer_items as $footer_item) {
    $footer_links_output .= $footer_item;
    if ($footer_links_current < $footer_links_count) {
      $footer_links_output .= $delimiter;
    }
    $footer_links_current++;
  }

  // Build footer and links if exists
  $footer_output = '';
  if (trim($output) && $footer_links_count) {
    $footer_output = $output .'<br />'. $leftcab . $footer_links_output . $rightcab;
  }
  elseif (!trim($output) && $footer_links_count) {
    $footer_output = $leftcab . $footer_links_output . $rightcab;
  }
  else {
    $footer_output = $output;
  }

  // Return footer
  return $footer_output;
}

/**
 * We will detect if client is Internet Explorer. Then we are able to add
 * the XML prolog for XHTML Standard Compliance Mode for other browsers.
 *
 * Today IE is the only known software we need to workaround and therefor we
 * only detect IE browser and suppose all other browsers render correctly with
 * XML prolog.
 */
function _browser_xml_prolog_compliant() {
  $ua = $_SERVER['HTTP_USER_AGENT'];

  if (eregi('msie', $ua) && !eregi('opera', $ua)) {
    // This is not a Opera pose as IE
    $clientdata = explode(' ', stristr($ua, 'msie'));
    $client['version'] = $clientdata[1];

    if ($client['version'] >= 7) {
      // IE >= 7.0: http://blogs.msdn.com/ie/archive/2005/09/15/467901.aspx
      $xml_prolog_compliant = TRUE;
    }
    else {
      // IE <= 6.0
      $xml_prolog_compliant = FALSE;
    }
  }
  else {
    // all other browsers
    $xml_prolog_compliant = TRUE;
  }

  return $xml_prolog_compliant;
}
