<?php
/**
 * "Yet Another Multicolumn Layout" for Drupal
 *
 * (en) Central template for theme specific functions
 * (de) Zentrales Template für theme spezifische Funktionen
 *
 * @copyright       Copyright 2006-2008, Alexander Hass
 * @license         http://www.yaml-fuer-drupal.de/en/terms-of-use
 * @link            http://www.yaml-for-drupal.com
 * @package         yaml-for-drupal
 * @version         5.x-3.0.4.8
 * @lastmodified    2008-02-28
 */

/**
 * Include the central template.inc with global theme functions
 */
include_once(realpath(dirname(__FILE__) .'/template.inc'));

/**
 * Alter some Drupal variables required by Theme
 */
function _phptemplate_variables($hook, $vars = array()) {
  switch ($hook) {
    case 'page':
      global $user;

      // Load the XML prolog for standard compliant browsers if caching is inactive.
      // The function page_set_cache() does not cache pages if $user->uid has a value.
      // Additional the XML prolog can only added to YAML for Drupal if a user is
      // logged into Drupal (caching inactive) or caching is globaly disabled on the site.
      if ((_browser_xml_prolog_compliant() && $user->uid) || (_browser_xml_prolog_compliant() && !(variable_get('cache', 0)))) {
        $vars['xml_prolog'] = '<?xml version="1.0" encoding="utf-8"?>' . "\n";
      }

      // Load region content assigned via drupal_set_content().
      if (module_exists('fontsize')) {
        foreach (array('fontsize_init', 'fontsize_links') as $region) {
          $vars[$region] = drupal_get_content($region);
        }
      }

      // Add YAML Theme styles
      $vars['css'] = _yaml_simple_add_css($vars);
      $vars['styles'] = _yaml_simple_add_styles($vars);

      break;
  }

  return $vars;
}

/**
 * Theme Regions
 */
function yaml_simple_regions() {
  return array(
    'left' => t('left sidebar'),
    'content' => t('content'),
    'header' => t('header'),
    'footer' => t('footer'),
  );
}

/**
 * Theme CSS files
 *
 * Workaround for CSS aggregate and compress feature in Drupal 5.x
 */
function _yaml_simple_add_css($vars = array()) {

  $base_theme_directory = $vars['directory'];

  // Add core and layout specific styles
  drupal_add_css($base_theme_directory .'/yaml/core/base.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/screen/basemod.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/screen/basemod_2col_13.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/screen/basemod_drupal.css', 'theme');

  // Add horizontal navigations
  //drupal_add_css($base_theme_directory .'/css/navigation/nav_shinybuttons.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/navigation/nav_slidingdoor.css', 'theme');

  // Add vertical navigations
  drupal_add_css($base_theme_directory .'/css/navigation/nav_vlist_drupal.css', 'theme');

  // Content CSS files
  drupal_add_css($base_theme_directory .'/css/screen/content.css', 'theme');

  // Add custom module styles
  _yaml_add_css_modules($base_theme_directory);

  // Add print CSS files
  drupal_add_css($base_theme_directory .'/yaml/core/print_base.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/print/print_003.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/print/print.css', 'theme');

  // Remove the style.css added as first array item and move it to the end
  // of the styles array. This allows to use themes style.css and keep
  // the required CSS cascading order intact for CSS overriding.
  $css = drupal_add_css();
  if (isset($css['all']['theme'][$vars['directory'] .'/style.css'])) {
    unset($css['all']['theme'][$vars['directory'] .'/style.css']);
    $css['all']['theme'][$vars['directory'] .'/style.css'] = TRUE;
  }

  // Return CSS array
  return $css;
}

function _yaml_simple_add_styles($vars = array()) {

  // Theme-Settings based on css/screen/basemod.css setting.
  $yaml_layout_page_width_min = '740px';
  $yaml_layout_page_width_max = '90em';

  $base_theme_directory = $vars['directory'];
  $styles = drupal_get_css($vars['css']);

  // The styles array is complete, get the styled css and append the
  // IE Hacks. Additional this allows to dynamically add packed or other iehacks.
  $styles .= "<!--[if lte IE 7]>\n";
  $styles .= '<style type="text/css" media="all">@import "'. base_path() . $base_theme_directory .'/yaml/core/iehacks'. (variable_get('preprocess_css', FALSE) ? '.pack' : '') .'.css";</style>' . "\n";
  $styles .= '<style type="text/css" media="all">@import "'. base_path() . $base_theme_directory .'/css/patches/patch_nav_vlist_drupal.css";</style>' . "\n";
  $styles .= '<style type="text/css" media="all">@import "'. base_path() . $base_theme_directory .'/css/patches/patch_2col_13.css";</style>' . "\n";
  $styles .= '<style type="text/css" media="all">@import "'. base_path() . $base_theme_directory .'/css/patches/patch_drupal.css";</style>' . "\n";
  $styles .= "<![endif]-->\n";

  // IE 6 settings and styles.
  $styles .= "<!--[if lte IE 6]>\n";
  $styles .= '<style type="text/css">';
  $styles .= 'img, .pngtrans { behavior: url('. base_path() . $base_theme_directory .'/images/pngfix/iepngfix.htc) }';
  $styles .= '* html #page_margins { width: '. $yaml_layout_page_width_max .'; width: expression((document.documentElement && document.documentElement.clientHeight) ? (document.documentElement.clientWidth < '. preg_replace('/[\D]+/', '', $yaml_layout_page_width_min) .') ? "'. $yaml_layout_page_width_min .'" : (( document.documentElement.clientWidth > ('. preg_replace('/[\D]+/', '', $yaml_layout_page_width_max) * round((83/75), 2) .' * parseInt(document.documentElement.currentStyle.fontSize))) ? "'. $yaml_layout_page_width_max .'" : "auto") : (document.body.clientWidth < '. preg_replace('/[\D]+/', '', $yaml_layout_page_width_min) .') ? "'. $yaml_layout_page_width_min .'" : (( document.body.clientWidth > ('. preg_replace('/[\D]+/', '', $yaml_layout_page_width_max) * round((83/75), 2) .' * parseInt(document.body.currentStyle.fontSize))) ? "'. $yaml_layout_page_width_max .'" : "auto"));}';
  $styles .= "</style>\n";
  $styles .= "<![endif]-->\n";

  // Return themed styles
  return $styles;
}
